/*
 * @Company: hugeInfo
 * @Author: xzx
 * @Date: 2022-04-19 11:27:07
 * @LastEditors: ldh
 * @LastEditTime: 2022-11-01 17:43:25
 * @Version: 1.0.0
 * @Description: 司法确认申请审查列表
 */
import React, { useEffect, useState } from 'react';
import { Form, Typography } from 'antd';
import { useLocation, useNavigate } from 'react-router-dom';
import * as $$ from '../../../utils/utility';
import Page from '../../../components/Page';
import TableView from '../../../components/TableView';
import TableSearch from '../../../components/TableSearch';
import publicDataStatus from '../../../status/publicData';

const { Link } = Typography;

// 获取司法确认审查列表数据
function getCourtOfficeDataApi(submitData) {
	return $$.ax.request({ url: 'judicTask/pageCourtAudit', type: 'get', data: submitData, service: 'mediate' });
}

const CourtOffice = () => {
	const [form] = Form.useForm();

	const location = useLocation();

	const navigate = useNavigate();

	// 搜索
	const [search, setSearch] = useState({ page: 1, size: 10 });

	// 数据
	const [data, setData] = useState({ tableData: [] });

	// 调解组织select框数据
	const [adjustOrgData, setAdjustOrgData] = useState([]);

	// 表头
	const columns = [
		{ title: '调解案号', dataIndex: 'caseNo' },
		{ title: '申请时间', dataIndex: 'applyTime' },
		{
			title: '审查标签',
			dataIndex: 'auditTag',
			render: (text, record) => <div className={`public-tag public-tag-${text === '1' ? 'tagBlue2' : 'tagOrange'}`}>{record.auditTagName}</div>,
		},
		{ title: '调解组织', dataIndex: 'mediateUnitName' },
		{ title: '调解员', dataIndex: 'mediateUserName' },
		{ title: '调解成功时间', dataIndex: 'mediTime' },
		{ title: '申请人', dataIndex: 'plaintiffs' },
		{ title: '被申请人', dataIndex: 'defendants' },
		{ title: '纠纷类型', dataIndex: 'caseTypeName' },
		{ title: '纠纷发生地详址', dataIndex: 'addr' },
		{
			title: '操作',
			dataIndex: 'action',
			width: 50,
			render: (_, record) => <Link onClick={() => handleJump(record)}>审查</Link>,
		},
	];

	// 审查跳转
	function handleJump(info) {
		$$.setSessionStorage(location.pathname, {
			search,
			tableActive: info.id,
		});
		navigate(`/mediate/courtOffice/judicialAudit?taskId=${info.id}&back=${location.pathname}`);
	}

	// 页码修改
	function handleChangePage(page, pageSize) {
		getCourtOfficeData({ ...search, page, size: pageSize });
	}

	// 搜索 or 重置
	function handleSearch(type, session) {
		let paramsObj = {};
		if (type === 'search') {
			paramsObj = { ...search, ...form.getFieldsValue(), page: 1 };
			$$.changeTimeFormat(paramsObj, 'applyTime', 'applyStart', 'applyEnd');
		}
		if (type === 'reset') {
			form.resetFields();
			paramsObj = { page: 1, size: 10 };
		}
		if (type === 'recurrent') {
			paramsObj = { ...search, ...session.search };
			let copyObj = { ...paramsObj };
			if (copyObj.applyStart) {
				copyObj.applyTime = [$$.myMoment(copyObj.applyStart), $$.myMoment(copyObj.applyEnd)];
			}
			form.setFieldsValue(copyObj);
		}
		getCourtOfficeData(paramsObj, session?.tableActive);
	}

	// 获取数据
	async function getCourtOfficeData(submitData, tableActive) {
		global.setSpinning(true);
		const res = await getCourtOfficeDataApi(submitData);
		global.setSpinning(false);
		if (res.type) {
			setSearch(submitData);
			setData({ total: res.data?.totalElements, tableData: res.data?.content || [], tableActive });
		}
	}

	// 初始化
	useEffect(() => {
		publicDataStatus.getUnitData((data) => setAdjustOrgData(data));
		let values = $$.getSessionStorage(location.pathname);
		if ($$.getQueryString('isBack') && !!values) {
			handleSearch('recurrent', values);
		} else {
			handleSearch('reset');
		}
		if (!!values) {
			$$.clearSessionStorage(location.pathname);
		}
	}, []);

	return (
		<Page pageHead={{ title: '司法确认申请审查', subtitle: '审查与管理司法确认案件' }}>
			<div className="courtOffice">
				<div className="pageSearch">
					<TableSearch
						form={form}
						itemData={[
							{ type: 'Input', name: 'plaintiffs', label: '申请人' },
							{ type: 'Input', name: 'defendants', label: '被申请人' },
							{ type: 'RangePicker', name: 'applyTime', label: '申请时间' },
							{ type: 'TreeSelect', name: 'applyUnitId', label: '调解组织', treedata: adjustOrgData },
							{ type: 'Input', name: 'addr', label: '纠纷发生地' },
							{ type: 'Input', name: 'caseNo', label: '调解案号' },
						]}
						handleReset={() => handleSearch('reset')}
						handleSearch={() => handleSearch('search')}
					/>
				</div>
				<div className="pageTable">
					<TableView
						showHeader
						title="查询结果"
						columns={columns}
						dataSource={data.tableData}
						pagination={{
							current: search.page,
							pageSize: search.size,
							total: data.total,
							onChange: (page, pageSize) => handleChangePage(page, pageSize),
						}}
						rowClassName={(record) => (record.id === data.tableActive ? 'tableRowActive' : '')}
					/>
				</div>
			</div>
		</Page>
	);
};

export default CourtOffice;
